Add Encoders:

ChunkedBase: 45, 85_ascii, 85_z85
GenericBase: 36, 36_lower, 58_bitcoin, 58_flickr, 58_ripple, 62
Base91
Bech32

CRC16
CRC32
Adler-32
FNV-1/FNV-1a

Binary

Unicode Half Width
Unicode Full Width
Punycode

Toy Encoders:

Rot13
Reverse